@@ -34,7 +34,7 @@ from .assertions import (
     )
 from .test import Test
 from .test_context import TestContext, with_context
-from .utils import skip_test, skipped
+from .utils import skip_test, skipped, add_error, add_failure
 from .test import abstract_test_class
 from .app import get_application_context
 from .runner import run_tests
