@@ -1,4 +1,5 @@
 from .ctx import context
+from .exception_handling import handling_exceptions
 import logbook
 
 _logger = logbook.Logger(__name__)
@@ -37,9 +38,10 @@ def call_cleanups(critical_only=False):
         if critical_only and not cleanup.critical:
             continue
         try:
-            cleanup()
+            with handling_exceptions():
+                cleanup()
         except:
-            context.session.get_result(context.test).add_error()
+            context.session.results.get_result(context.test).add_error()
 
 def _get_cleanups():
     returned = getattr(context, "cleanups", None)
