@@ -1,20 +1,18 @@
 import sys
+from contextlib import contextmanager
+
+import logbook
+
 from . import hooks
+from ._compat import ExitStack
 from .cleanups import call_cleanups
 from .conf import config
 from .ctx import context
-from .exceptions import (
-    NoActiveSession,
-    SkipTest,
-    TestFailed,
-    )
 from .exception_handling import handling_exceptions
+from .exceptions import NoActiveSession, SkipTest, TestFailed
 from .metadata import ensure_test_metadata
 from .test_context import get_test_context_setup
 from .utils.peekable_iterator import PeekableIterator
-from contextlib import contextmanager
-from ._compat import ExitStack
-import logbook # pylint: disable=F0401
 
 _logger = logbook.Logger(__name__)
 
@@ -28,8 +26,9 @@ def run_tests(iterable):
     for test in test_iterator:
         ensure_test_metadata(test)
         _logger.debug("Running {0}...", test)
-        with _get_run_context_stack(test, test_iterator) as result:
+        with _get_run_context_stack(test, test_iterator):
             test.run()
+        result = context.session.results[test]
         if not result.is_success() and not result.is_skip() and config.root.run.stop_on_error:
             _logger.debug("Stopping (run.stop_on_error==True)")
             break
@@ -42,16 +41,16 @@ def _get_run_context_stack(test, test_iterator):
     with ExitStack() as stack:
         stack.enter_context(_get_test_context(test))
         stack.enter_context(_get_test_hooks_context())
-        result = stack.enter_context(_update_result_context())
+        stack.enter_context(_update_result_context())
         stack.enter_context(_cleanup_context())
         stack.enter_context(handling_exceptions())
         stack.enter_context(get_test_context_setup(test, test_iterator.peek_or_none()))
         yielded = True
-        yield result
+        yield
     # if some of the context entries throw SkipTest, the yield result above will not be reached.
     # we have to make sure that yield happens or else the context manager will raise on __exit__...
     if not yielded:
-        yield result
+        yield
 
 @contextmanager
 def _cleanup_context():
@@ -110,7 +109,7 @@ def _set_current_test_context(test):
 
 @contextmanager
 def _update_result_context():
-    result = context.session.create_result(context.test)
+    result = context.session.results.create_result(context.test)
     try:
         try:
             yield result
